<?php

if(!function_exists('gotravel_mikado_woocommerce_products_per_page')) {
    /**
     * Function that sets number of products per page. Default is 12
     * @return int number of products to be shown per page
     */
    function gotravel_mikado_woocommerce_products_per_page() {
        $products_per_page = 12;

        if(gotravel_mikado_options()->getOptionValue('mkdf_woo_products_per_page')) {
            $products_per_page = gotravel_mikado_options()->getOptionValue('mkdf_woo_products_per_page');
        }

        return $products_per_page;
    }
}

if(!function_exists('gotravel_mikado_woocommerce_related_products_args')) {
    /**
     * Function that sets number of displayed related products. Hooks to woocommerce_output_related_products_args filter
     *
     * @param $args array array of args for the query
     *
     * @return mixed array of changed args
     */
    function gotravel_mikado_woocommerce_related_products_args($args) {

        if(gotravel_mikado_options()->getOptionValue('mkdf_woo_product_list_columns')) {

            $related = gotravel_mikado_options()->getOptionValue('mkdf_woo_product_list_columns');
            switch($related) {
                case 'mkdf-woocommerce-columns-4':
                    $args['posts_per_page'] = 4;
                    break;
                case 'mkdf-woocommerce-columns-3':
                    $args['posts_per_page'] = 3;
                    break;
                default:
                    $args['posts_per_page'] = 3;
            }
        } else {
            $args['posts_per_page'] = 3;
        }

        return $args;
    }
}

if(!function_exists('gotravel_mikado_woocommerce_template_loop_product_title')) {
    /**
     * Function for overriding product title template in Product List Loop
     */
    function gotravel_mikado_woocommerce_template_loop_product_title() {

        $tag = gotravel_mikado_options()->getOptionValue('mkdf_products_list_title_tag');
        the_title('<'.$tag.' class="mkdf-product-list-product-title">', '</'.$tag.'>');
    }
}

if(!function_exists('gotravel_mikado_woocommerce_template_single_title')) {
    /**
     * Function for overriding product title template in Single Product template
     */
    function gotravel_mikado_woocommerce_template_single_title() {

        $tag = gotravel_mikado_options()->getOptionValue('mkdf_single_product_title_tag');
        the_title('<'.$tag.'  itemprop="name" class="mkdf-single-product-title">', '</'.$tag.'>');
    }
}

if (!function_exists('gotravel_mikado_woocommerce_review_display_meta')) {
    /**
     * Function that overrides default woocommerce review display meta
     * Adds placeholders
     *
     * @param $comment_form
     * @return mixed
     */
    function gotravel_mikado_woocommerce_review_display_meta($comment_form) {
		global $comment;

		$verified = wc_review_is_from_verified_owner( $comment->comment_ID );

		if ( '0' === $comment->comment_approved ) { ?>
			<p class="meta"><em><?php esc_html_e( 'Your comment is awaiting approval', 'gotravel' ); ?></em></p>
		<?php } else { ?>
			<p class="meta">
				<strong itemprop="author"><?php comment_author(); ?></strong>
				<?php if (get_option( 'woocommerce_review_rating_verification_label' ) === 'yes' && $verified) {
					echo '<em class="verified">(' . esc_html__( 'verified owner', 'gotravel' ) . ')</em> ';
				}
				?>
			</p>
		<?php }
    }
}

if(!function_exists('gotravel_mikado_woocommerce_sale_flash')) {
    /**
     * Function for overriding Sale Flash Template
     *
     * @return string
     */
    function gotravel_mikado_woocommerce_sale_flash() {
        return '<span class="mkdf-onsale"><span class="mkdf-onsale-inner">'.esc_html__('Sale', 'gotravel').'</span></span>';
    }
}

if(!function_exists('gotravel_mikado_woocommerce_loop_add_to_cart_link')) {
    /**
     * Function that overrides default woocommerce add to cart button on product list
     * Uses HTML from mkdf_button
     *
     * @return mixed|string
     */
    function gotravel_mikado_woocommerce_loop_add_to_cart_link() {
        global $product;

        $button_url     = $product->add_to_cart_url();
        $button_classes = sprintf('%s product_type_%s %s',
            $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : 'mkdf-product-out-of-stock',
            esc_attr($product->get_type()),
			esc_attr($product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart ' : ' ')
        );
	    
        $button_text    = $product->add_to_cart_text();
        $button_attrs   = array(
            'rel'              => 'nofollow',
            'data-product_id'  => esc_attr($product->get_id()),
            'data-product_sku' => esc_attr($product->get_sku()),
            'data-quantity'    => esc_attr(isset($quantity) ? $quantity : 1)
        );
        
        $button_params = array(
	        'link'         => $button_url,
	        'custom_class' => $button_classes,
	        'text'         => $button_text,
	        'custom_attrs' => $button_attrs
        );

        if ( gotravel_mikado_core_plugin_installed() ) {
	        $add_to_cart_button = gotravel_mikado_get_button_html( $button_params );
        } else {
	        $add_to_cart_button = '<a href="'.$button_params['link'].'" target="_self" class="mkdf-btn mkdf-btn-medium mkdf-btn-solid add_to_cart_button product_type_simple ajax_add_to_cart  mkdf-btn-hover-solid" rel="nofollow" data-product_id="'.$button_params['custom_attrs']['data-product_id'].'" data-product_sku="'.$button_params['custom_attrs']['data-product_sku'].'" data-quantity="'.$button_params['custom_attrs']['data-quantity'].'"><span class="mkdf-btn-text">'.$button_params['text'].'</span><span class="mkdf-btn-helper"></span></a>';
        }

        return $add_to_cart_button;
    }
}

if(!function_exists('gotravel_mikado_get_woocommerce_add_to_cart_button')) {
    /**
     * Function that overrides default woocommerce add to cart button on simple and grouped product single template
     * Uses HTML from mkdf_button
     */
    function gotravel_mikado_get_woocommerce_add_to_cart_button() {
        global $product;
        $button_params = array(
	        'custom_class'      => 'single_add_to_cart_button button alt',
	        'text'              => $product->single_add_to_cart_text(),
	        'html_type'         => 'button',
	        'icon_pack'         => 'simple_line_icons',
	        'simple_line_icons' => 'icon-basket',
	        'size'              => 'small',
	        'custom_attrs'   => array('name' => 'add-to-cart', 'value' => esc_attr( $product->get_id() ))
        );

        if ( gotravel_mikado_core_plugin_installed() ) {
	        $add_to_cart_button = gotravel_mikado_get_button_html($button_params);
        } else {
        	$add_to_cart_button = '<button type="submit" name="'.$button_params['custom_attrs']['name'].'" value="'.$button_params['custom_attrs']['value'].'" class="mkdf-btn mkdf-btn-small mkdf-btn-solid single_add_to_cart_button button alt mkdf-btn-hover-solid">';
			$add_to_cart_button .= '<span class="mkdf-btn-text">'.$button_params['text'].'</span><span class="mkdf-btn-helper"></span></button>';
        }

        echo gotravel_mikado_get_module_part($add_to_cart_button);
    }
}

if(!function_exists('gotravel_mikado_get_woocommerce_add_to_cart_button_external')) {
    /**
     * Function that overrides default woocommerce add to cart button on external product single template
     * Uses HTML from mkdf_button
     */
    function gotravel_mikado_get_woocommerce_add_to_cart_button_external() {
        global $product;
        $button_params = array(
	        'link'         => $product->add_to_cart_url(),
	        'custom_class'   => 'single_add_to_cart_button button alt',
	        'text'           => $product->single_add_to_cart_text(),
	        'custom_attrs'   => array(
		        'rel' => 'nofollow'
	        ),
        );

        if ( gotravel_mikado_core_plugin_installed() ) {
	        $add_to_cart_button = gotravel_mikado_get_button_html( $button_params );
        } else {
        	$add_to_cart_button = '<a href="'.$button_params['link'].'" target="_self" class="mkdf-btn mkdf-btn-medium mkdf-btn-solid single_add_to_cart_button button alt mkdf-btn-hover-solid" rel="nofollow">';
	        $add_to_cart_button .= '<span class="mkdf-btn-text">'.$button_params['text'].'</span><span class="mkdf-btn-helper"></span></a>';
        }

        echo gotravel_mikado_get_module_part($add_to_cart_button);
    }
}

if(!function_exists('gotravel_mikado_woocommerce_single_variation_add_to_cart_button')) {
    /**
     * Function that overrides default woocommerce add to cart button on variable product single template
     * Uses HTML from mkdf_button
     */
    function gotravel_mikado_woocommerce_single_variation_add_to_cart_button() {
        global $product;
        $button_params = array(
	        'html_type'    => 'button',
	        'custom_class' => 'single_add_to_cart_button button alt',
	        'text'         => $product->single_add_to_cart_text()
        );

        $html = '<div class="variations_button">';
        woocommerce_quantity_input(array('input_value' => isset($_POST['quantity']) ? wc_stock_amount($_POST['quantity']) : 1));

        if ( gotravel_mikado_core_plugin_installed() ) {
	        $button = gotravel_mikado_get_button_html( $button_params );
        } else {
        	$button = '<button type="submit" class="mkdf-btn mkdf-btn-medium mkdf-btn-solid single_add_to_cart_button button alt mkdf-btn-hover-solid disabled wc-variation-selection-needed">';
	        $button .= '<span class="mkdf-btn-text">'.$button_params['text'].'</span><span class="mkdf-btn-helper"></span></button>';
        }

        $html .= $button;

        $html .= '<input type="hidden" name="add-to-cart" value="'.absint($product->get_id()).'" />';
        $html .= '<input type="hidden" name="product_id" value="'.absint($product->get_id()).'" />';
        $html .= '<input type="hidden" name="variation_id" class="variation_id" value="" />';
        $html .= '</div>';

        echo gotravel_mikado_get_module_part($html);
    }
}

if(!function_exists('gotravel_mikado_get_woocommerce_apply_coupon_button')) {
    /**
     * Function that overrides default woocommerce apply coupon button
     * Uses HTML from mkdf_button
     */
    function gotravel_mikado_get_woocommerce_apply_coupon_button() {
    	$button_params = array(
		    'html_type'  => 'input',
		    'input_name' => 'apply_coupon',
		    'text'       => esc_html__('Apply Coupon', 'gotravel')
	    );
    	
    	if ( gotravel_mikado_core_plugin_installed() ) {
		    $coupon_button = gotravel_mikado_get_button_html( $button_params );
	    } else {
    		$coupon_button = '<input type="submit" name="'.$button_params['input_name'].'" value="'.$button_params['text'].'" class="mkdf-btn mkdf-btn-medium mkdf-btn-solid mkdf-btn-hover-solid">';
	    }

        echo gotravel_mikado_get_module_part($coupon_button);
    }
}

if(!function_exists('gotravel_mikado_get_woocommerce_update_cart_button')) {
    /**
     * Function that overrides default woocommerce update cart button
     * Uses HTML from mkdf_button
     */
    function gotravel_mikado_get_woocommerce_update_cart_button() {
    	$button_params = array(
		    'html_type'  => 'input',
		    'input_name' => 'update_cart',
		    'text'       => esc_html__('Update Cart', 'gotravel')
	    );
    	
    	if ( gotravel_mikado_core_plugin_installed() ) {
		    $update_cart_button = gotravel_mikado_get_button_html( $button_params );
	    } else {
    		$update_cart_button = '<input type="submit" name="'.$button_params['input_name'].'" value="'.$button_params['text'].'" class="mkdf-btn mkdf-btn-medium mkdf-btn-solid mkdf-btn-hover-solid" disabled="">';
	    }

        echo gotravel_mikado_get_module_part($update_cart_button);
    }
}

if(!function_exists('gotravel_mikado_woocommerce_button_proceed_to_checkout')) {
    /**
     * Function that overrides default woocommerce proceed to checkout button
     * Uses HTML from mkdf_button
     */
    function gotravel_mikado_woocommerce_button_proceed_to_checkout() {
    	$button_params = array(
		    'link'         => wc_get_checkout_url(),
		    'custom_class' => 'checkout-button alt wc-forward',
		    'text'         => esc_html__('Proceed to Checkout', 'gotravel')
	    );
    	
    	if ( gotravel_mikado_core_plugin_installed() ) {
		    $proceed_to_checkout_button = gotravel_mikado_get_button_html( $button_params );
	    } else {
    		$proceed_to_checkout_button = '<a href="'.$button_params['link'].'" target="_self" class="mkdf-btn mkdf-btn-medium mkdf-btn-solid checkout-button alt wc-forward mkdf-btn-hover-solid"><span class="mkdf-btn-text">'.$button_params['text'].'</span><span class="mkdf-btn-helper"></span></a>';
	    }

        echo gotravel_mikado_get_module_part($proceed_to_checkout_button);
    }
}

if(!function_exists('gotravel_mikado_get_woocommerce_update_totals_button')) {
    /**
     * Function that overrides default woocommerce update totals button
     * Uses HTML from mkdf_button
     */
    function gotravel_mikado_get_woocommerce_update_totals_button() {
    	$button_params = array(
		    'html_type'    => 'button',
		    'text'         => esc_html__('Update Totals', 'gotravel'),
		    'custom_attrs' => array(
			    'value' => 1,
			    'name'  => 'calc_shipping'
		    )
	    );
    	
    	if ( gotravel_mikado_core_plugin_installed() ) {
		    $update_totals_button = gotravel_mikado_get_button_html( $button_params );
	    } else {
    		$update_totals_button = '<button type="submit" value="'.$button_params['custom_attrs']['value'].'" name="'.$button_params['custom_attrs']['name'].'" class="mkdf-btn mkdf-btn-medium mkdf-btn-solid mkdf-btn-hover-solid"><span class="mkdf-btn-text">'.$button_params['text'].'</span><span class="mkdf-btn-helper"></span></button>';
	    }

        echo gotravel_mikado_get_module_part($update_totals_button);
    }
}

if(!function_exists('gotravel_mikado_woocommerce_pay_order_button_html')) {
    /**
     * Function that overrides default woocommerce pay order button on checkout page
     * Uses HTML from mkdf_button
     */
    function gotravel_mikado_woocommerce_pay_order_button_html() {
        $pay_order_button_text = esc_html__('Pay for order', 'gotravel');
        $button_params = array(
	        'html_type'    => 'input',
	        'custom_class' => 'alt',
	        'custom_attrs' => array(
		        'id'         => 'place_order',
		        'data-value' => $pay_order_button_text
	        ),
	        'text'         => $pay_order_button_text,
        );
	       
        if ( gotravel_mikado_core_plugin_installed() ) {
	        $pay_order_button = gotravel_mikado_get_button_html( $button_params );
        } else {
        	$pay_order_button = '<input type="submit" name="" value="'.$button_params['text'].'" class="mkdf-btn mkdf-btn-medium mkdf-btn-solid alt mkdf-btn-hover-solid" id="'.$button_params['custom_attrs']['id'].'" data-value="'.$button_params['custom_attrs']['data-value'].'">';
        }

        return $pay_order_button;
    }
}

if(!function_exists('gotravel_mikado_woocommerce_order_button_html')) {
    /**
     * Function that overrides default woocommerce place order button on checkout page
     * Uses HTML from mkdf_button
     */
    function gotravel_mikado_woocommerce_order_button_html() {
        $place_order_button_text = esc_html__('Place Order', 'gotravel');
        $button_params = array(
	        'html_type'    => 'input',
	        'custom_class' => 'alt',
	        'custom_attrs' => array(
		        'id'         => 'place_order',
		        'data-value' => $place_order_button_text,
		        'name'       => 'woocommerce_checkout_place_order'
	        ),
	        'text'         => $place_order_button_text,
        );

        if ( gotravel_mikado_core_plugin_installed() ) {
	        $place_order_button = gotravel_mikado_get_button_html( $button_params );
        } else {
        	$place_order_button = '<input type="submit" name="" value="'.$button_params['text'].'" class="mkdf-btn mkdf-btn-medium mkdf-btn-solid alt mkdf-btn-hover-solid" id="'.$button_params['custom_attrs']['id'].'" data-value="'.$button_params['custom_attrs']['data-value'].'">';
        }

        return $place_order_button;
    }
}